=================
How to Contribute
=================

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the Heat Dashboard project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * https://docs.openstack.org/infra/manual/developers.html
   * https://wiki.openstack.org/CLA


Project Hosting Details
-------------------------

Bug tracker
    https://storyboard.openstack.org/#!/project/992

Code Hosting
    https://git.openstack.org/cgit/openstack/heat-dashboard

Code Review
    https://review.openstack.org/#/q/status:open+project:openstack/heat-dashboard,n,z
